==> qtjambi-nfc-6.6.1-sources.jar: io/qt/nfc/QNdefNfcTextRecord.java <==
package io.qt.nfc;

import io.qt.*;


/**
 * <p>NFC RTD-Text</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qndefnfctextrecord.html">QNdefNfcTextRecord</a></code></p>
 */
public class QNdefNfcTextRecord extends io.qt.nfc.QNdefRecord
    implements java.lang.Cloneable
{
    /**
     * <p>Java wrapper for Qt enum <code><a href="https://doc.qt.io/qt/qndefnfctextrecord.html#Encoding-enum">QNdefNfcTextRecord::Encoding</a></code></p>
     */
    public enum Encoding implements QtEnumerator {
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qndefnfctextrecord.html#Encoding-enum">QNdefNfcTextRecord::<wbr/>Utf8</a></code></p>
         */
        Utf8(0),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qndefnfctextrecord.html#Encoding-enum">QNdefNfcTextRecord::<wbr/>Utf16</a></code></p>
         */
        Utf16(1);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private Encoding(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static @NonNull Encoding resolve(int value) {
            switch (value) {
            case 0: return Utf8;
            case 1: return Utf16;
            default: throw new QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qndefnfctextrecord.html#QNdefNfcTextRecord">QNdefNfcTextRecord::<wbr/>QNdefNfcTextRecord()</a></code></p>
     */
    public QNdefNfcTextRecord(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QNdefNfcTextRecord instance);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qndefnfctextrecord.html#QNdefNfcTextRecord-1">QNdefNfcTextRecord::<wbr/>QNdefNfcTextRecord(QNdefRecord)</a></code></p>
     */
    public QNdefNfcTextRecord(io.qt.nfc.@NonNull QNdefRecord other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QNdefNfcTextRecord instance, io.qt.nfc.QNdefRecord other);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qndefnfctextrecord.html#encoding">QNdefNfcTextRecord::<wbr/>encoding()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.nfc.QNdefNfcTextRecord.@NonNull Encoding encoding(){
        return io.qt.nfc.QNdefNfcTextRecord.Encoding.resolve(encoding_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @QtUninvokable
    private native int encoding_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qndefnfctextrecord.html#locale">QNdefNfcTextRecord::<wbr/>locale()const</a></code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String locale(){
        return locale_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String locale_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qndefnfctextrecord.html#setEncoding">QNdefNfcTextRecord::<wbr/>setEncoding(QNdefNfcTextRecord::Encoding)</a></code></p>
     */
    @QtUninvokable
    public final void setEncoding(io.qt.nfc.QNdefNfcTextRecord.@NonNull Encoding encoding){
        setEncoding_native_QNdefNfcTextRecord_Encoding(QtJambi_LibraryUtilities.internal.nativeId(this), encoding.value());
    }
    
    @QtUninvokable
    private native void setEncoding_native_QNdefNfcTextRecord_Encoding(long __this__nativeId, int encoding);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qndefnfctextrecord.html#setLocale">QNdefNfcTextRecord::<wbr/>setLocale(QString)</a></code></p>
     */
    @QtUninvokable
    public final void setLocale(java.lang.@NonNull String locale){
        setLocale_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), locale);
    }
    
    @QtUninvokable
    private native void setLocale_native_cref_QString(long __this__nativeId, java.lang.String locale);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qndefnfctextrecord.html#setText">QNdefNfcTextRecord::<wbr/>setText(QString)</a></code></p>
     */
    @QtUninvokable
    public final void setText(java.lang.@NonNull String text){
        setText_native_const_QString(QtJambi_LibraryUtilities.internal.nativeId(this), text);
    }
    
    @QtUninvokable
    private native void setText_native_const_QString(long __this__nativeId, java.lang.String text);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qndefnfctextrecord.html#text">QNdefNfcTextRecord::<wbr/>text()const</a></code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String text(){
        return text_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String text_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QNdefNfcTextRecord(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QNdefNfcTextRecord clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QNdefNfcTextRecord clone_native(long __this_nativeId);
}

==> qtjambi-nfc-6.6.2-sources.jar: io/qt/nfc/QNdefNfcTextRecord.java <==
package io.qt.nfc;

import io.qt.*;


/**
 * <p>NFC RTD-Text</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qndefnfctextrecord.html">QNdefNfcTextRecord</a></code></p>
 */
public class QNdefNfcTextRecord extends io.qt.nfc.QNdefRecord
    implements java.lang.Cloneable
{
    /**
     * <p>Java wrapper for Qt enum <code><a href="https://doc.qt.io/qt/qndefnfctextrecord.html#Encoding-enum">QNdefNfcTextRecord::Encoding</a></code></p>
     */
    public enum Encoding implements QtEnumerator {
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qndefnfctextrecord.html#Encoding-enum">QNdefNfcTextRecord::<wbr/>Utf8</a></code></p>
         */
        Utf8(0),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qndefnfctextrecord.html#Encoding-enum">QNdefNfcTextRecord::<wbr/>Utf16</a></code></p>
         */
        Utf16(1);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private Encoding(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static @NonNull Encoding resolve(int value) {
            switch (value) {
            case 0: return Utf8;
            case 1: return Utf16;
            default: throw new QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qndefnfctextrecord.html#QNdefNfcTextRecord">QNdefNfcTextRecord::<wbr/>QNdefNfcTextRecord()</a></code></p>
     */
    public QNdefNfcTextRecord(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QNdefNfcTextRecord instance);
    
    /**
     * <p>See <code>QNdefNfcTextRecord::<wbr/>QNdefNfcTextRecord(QNdefNfcTextRecord)</code></p>
     */
    public QNdefNfcTextRecord(io.qt.nfc.@NonNull QNdefNfcTextRecord other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QNdefNfcTextRecord instance, io.qt.nfc.QNdefNfcTextRecord other);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qndefnfctextrecord.html#QNdefNfcTextRecord-1">QNdefNfcTextRecord::<wbr/>QNdefNfcTextRecord(QNdefRecord)</a></code></p>
     */
    public QNdefNfcTextRecord(io.qt.nfc.@NonNull QNdefRecord other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QNdefNfcTextRecord instance, io.qt.nfc.QNdefRecord other);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qndefnfctextrecord.html#encoding">QNdefNfcTextRecord::<wbr/>encoding()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.nfc.QNdefNfcTextRecord.@NonNull Encoding encoding(){
        return io.qt.nfc.QNdefNfcTextRecord.Encoding.resolve(encoding_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @QtUninvokable
    private native int encoding_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qndefnfctextrecord.html#locale">QNdefNfcTextRecord::<wbr/>locale()const</a></code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String locale(){
        return locale_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String locale_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qndefnfctextrecord.html#setEncoding">QNdefNfcTextRecord::<wbr/>setEncoding(QNdefNfcTextRecord::Encoding)</a></code></p>
     */
    @QtUninvokable
    public final void setEncoding(io.qt.nfc.QNdefNfcTextRecord.@NonNull Encoding encoding){
        setEncoding_native_QNdefNfcTextRecord_Encoding(QtJambi_LibraryUtilities.internal.nativeId(this), encoding.value());
    }
    
    @QtUninvokable
    private native void setEncoding_native_QNdefNfcTextRecord_Encoding(long __this__nativeId, int encoding);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qndefnfctextrecord.html#setLocale">QNdefNfcTextRecord::<wbr/>setLocale(QString)</a></code></p>
     */
    @QtUninvokable
    public final void setLocale(java.lang.@NonNull String locale){
        setLocale_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), locale);
    }
    
    @QtUninvokable
    private native void setLocale_native_cref_QString(long __this__nativeId, java.lang.String locale);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qndefnfctextrecord.html#setText">QNdefNfcTextRecord::<wbr/>setText(QString)</a></code></p>
     */
    @QtUninvokable
    public final void setText(java.lang.@NonNull String text){
        setText_native_const_QString(QtJambi_LibraryUtilities.internal.nativeId(this), text);
    }
    
    @QtUninvokable
    private native void setText_native_const_QString(long __this__nativeId, java.lang.String text);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qndefnfctextrecord.html#text">QNdefNfcTextRecord::<wbr/>text()const</a></code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String text(){
        return text_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String text_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QNdefNfcTextRecord(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Creates and returns a copy of this object.</p>
    <p>See <code>QNdefNfcTextRecord::<wbr/>QNdefNfcTextRecord(QNdefNfcTextRecord)</code></p>
     */
    @QtUninvokable
    @Override
    public QNdefNfcTextRecord clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QNdefNfcTextRecord clone_native(long __this_nativeId);
}
